@@ -62,24 +62,24 @@ getSizeMean <- function(design=c("parallel", "crossover"),
 
   m <- (1-rho[1]-rho[2])*TTE
 
-  if(design == "parallel" & test == "equality") n_trt <- ceiling((TrialSize::TwoSampleMean.Equality(alpha, beta, sigma, k, margin=m))/(1-r))
+  if(design == "parallel" & test == "equality") n_ctl <- ceiling((TrialSize::TwoSampleMean.Equality(alpha, beta, sigma, k, margin=m))/(1-r))
 
-  if(design == "parallel" & test == "noninferiority") n_trt <- ceiling((TrialSize::TwoSampleMean.NIS(alpha, beta, sigma, k, delta, margin=m))/(1-r))
+  if(design == "parallel" & test == "noninferiority") n_ctl <- ceiling((TrialSize::TwoSampleMean.NIS(alpha, beta, sigma, k, delta, margin=m))/(1-r))
 
-  if(design == "parallel" & test == "superiority") n_trt <- ceiling((TrialSize::TwoSampleMean.NIS(alpha, beta, sigma, k, delta, margin=m))/(1-r))
+  if(design == "parallel" & test == "superiority") n_ctl <- ceiling((TrialSize::TwoSampleMean.NIS(alpha, beta, sigma, k, delta, margin=m))/(1-r))
 
-  if(design == "parallel" & test == "equivalence") n_trt <- ceiling((TrialSize::TwoSampleMean.Equivalence(alpha, beta, sigma, k, delta, margin=m))/(1-r))
+  if(design == "parallel" & test == "equivalence") n_ctl <- ceiling((TrialSize::TwoSampleMean.Equivalence(alpha, beta, sigma, k, delta, margin=m))/(1-r))
 
-  if(design == "crossover" & test == "equality") n_trt <- ceiling((TrialSize::TwoSampleCrossOver.Equality(alpha, beta, sigma, margin=m))/(1-r))
+  if(design == "crossover" & test == "equality") n_ctl <- ceiling((TrialSize::TwoSampleCrossOver.Equality(alpha, beta, sigma, margin=m))/(1-r))
 
-  if(design == "crossover" & test == "noninferiority" ) n_trt <- ceiling((TrialSize::TwoSampleCrossOver.NIS(alpha, beta, sigma,  delta, margin=m))/(1-r))
+  if(design == "crossover" & test == "noninferiority" ) n_ctl <- ceiling((TrialSize::TwoSampleCrossOver.NIS(alpha, beta, sigma,  delta, margin=m))/(1-r))
 
-  if(design == "crossover" & test == "superiority" ) n_trt <- ceiling((TrialSize::TwoSampleCrossOver.NIS(alpha, beta, sigma, delta, margin=m))/(1-r))
+  if(design == "crossover" & test == "superiority" ) n_ctl <- ceiling((TrialSize::TwoSampleCrossOver.NIS(alpha, beta, sigma, delta, margin=m))/(1-r))
 
-  if(design == "crossover" & test == "equivalence" ) n_trt <- ceiling((TrialSize::TwoSampleCrossOver.Equivalence(alpha, beta, sigma, delta, margin=m))/(1-r))
+  if(design == "crossover" & test == "equivalence" ) n_ctl <- ceiling((TrialSize::TwoSampleCrossOver.Equivalence(alpha, beta, sigma, delta, margin=m))/(1-r))
 
   ans <- stats::setNames(
-    data.frame(matrix(data = c(n_trt,k*n_trt), ncol=2, nrow=1), row.names="Size"),
+    data.frame(matrix(data = c((n_ctl/k), n_ctl), ncol=2, nrow=1), row.names="Size"),
     c("n_trt", "n_ctl"))
   return(ans)
 
@@ -164,24 +164,24 @@ getSizeProp <- function(design=c("parallel", "crossover"),
   varsigmaa1 <- rho[1]*varsigma[2]+(1-rho[1])*varsigma[1]
   varsigmaa2 <- rho[2]*varsigma[1]+(1-rho[2])*varsigma[2]
 
-  if(design == "parallel" & test == "equality") n_trt <- ceiling( (TrialSize::TwoSampleProportion.Equality(alpha, beta, p1=varsigmaa1, p2=varsigmaa2, k=k))/(1-r))
+  if(design == "parallel" & test == "equality") n_ctl <- ceiling( (TrialSize::TwoSampleProportion.Equality(alpha, beta, p1=varsigmaa1, p2=varsigmaa2, k=k))/(1-r))
 
-  if(design == "parallel" & test == "noninferiority") n_trt <- ceiling((TrialSize::TwoSampleProportion.NIS(alpha, beta, p1=varsigmaa1, p2=varsigmaa2, k=k, delta=(1-rho[1]-rho[2])*TTE, margin=delta))/(1-r))
+  if(design == "parallel" & test == "noninferiority") n_ctl <- ceiling((TrialSize::TwoSampleProportion.NIS(alpha, beta, p1=varsigmaa1, p2=varsigmaa2, k=k, delta=(1-rho[1]-rho[2])*TTE, margin=delta))/(1-r))
 
-  if(design == "parallel" & test == "superiority") n_trt <- ceiling( (TrialSize::TwoSampleProportion.NIS(alpha, beta, p1=varsigmaa1, p2=varsigmaa2, k=k, delta=(1-rho[1]-rho[2])*TTE, margin=delta))/(1-r))
+  if(design == "parallel" & test == "superiority") n_ctl <- ceiling( (TrialSize::TwoSampleProportion.NIS(alpha, beta, p1=varsigmaa1, p2=varsigmaa2, k=k, delta=(1-rho[1]-rho[2])*TTE, margin=delta))/(1-r))
 
-  if(design == "parallel" & test == "equivalence") n_trt <- ceiling( (TrialSize::TwoSampleProportion.Equivalence(alpha, beta,  p1=varsigmaa1, p2=varsigmaa2, k, delta=(1-rho[1]-rho[2])*TTE, margin=delta))/(1-r))
+  if(design == "parallel" & test == "equivalence") n_ctl <- ceiling( (TrialSize::TwoSampleProportion.Equivalence(alpha, beta,  p1=varsigmaa1, p2=varsigmaa2, k, delta=(1-rho[1]-rho[2])*TTE, margin=delta))/(1-r))
 
-  if(design == "crossover" & test == "equality") n_trt <- ceiling((TrialSize::TwoSampleSeqCrossOver.Equality(alpha, beta, sigma=(varsigma[1]**2), sequence=seqnumber, delta=(1-rho[1]-rho[2])*TTE))/(1-r))
+  if(design == "crossover" & test == "equality") n_ctl <- ceiling((TrialSize::TwoSampleSeqCrossOver.Equality(alpha, beta, sigma=(varsigma[1]**2), sequence=seqnumber, delta=(1-rho[1]-rho[2])*TTE))/(1-r))
 
-  if(design == "crossover" & test == "noninferiority") n_trt <- ceiling((TrialSize::TwoSampleSeqCrossOver.NIS(alpha, beta, sigma=(varsigma[1]**2), sequence=seqnumber, delta=delta, margin=(1-rho[1]-rho[2])*TTE))/(1-r))
+  if(design == "crossover" & test == "noninferiority") n_ctl <- ceiling((TrialSize::TwoSampleSeqCrossOver.NIS(alpha, beta, sigma=(varsigma[1]**2), sequence=seqnumber, delta=delta, margin=(1-rho[1]-rho[2])*TTE))/(1-r))
 
-  if(design == "crossover" & test == "superiority") n_trt <- ceiling((TrialSize::TwoSampleSeqCrossOver.NIS(alpha, beta, sigma=(varsigma[1]**2), sequence=seqnumber, delta=delta, margin=(1-rho[1]-rho[2])*TTE))/(1-r))
+  if(design == "crossover" & test == "superiority") n_ctl <- ceiling((TrialSize::TwoSampleSeqCrossOver.NIS(alpha, beta, sigma=(varsigma[1]**2), sequence=seqnumber, delta=delta, margin=(1-rho[1]-rho[2])*TTE))/(1-r))
 
-  if(design == "crossover" & test == "equivalence") n_trt <- ceiling((TrialSize::TwoSampleSeqCrossOver.Equivalence(alpha, beta, sigma=(varsigma[1]**2), sequence=seqnumber, delta=delta, margin=(1-rho[1]-rho[2])*TTE))/(1-r))
+  if(design == "crossover" & test == "equivalence") n_ctl <- ceiling((TrialSize::TwoSampleSeqCrossOver.Equivalence(alpha, beta, sigma=(varsigma[1]**2), sequence=seqnumber, delta=delta, margin=(1-rho[1]-rho[2])*TTE))/(1-r))
 
   ans <- stats::setNames(
-    data.frame(matrix(data = c(n_trt,k*n_trt),ncol=2, nrow=1), row.names="Size"),
+    data.frame(matrix(data = c((n_ctl/k),n_ctl),ncol=2, nrow=1), row.names="Size"),
     c("n_trt", "n_ctl"))
 
   return(ans)
